client

package
v1.5.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 1, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func PrepareRequest

func PrepareRequest(group, id string) (io.Reader, error)

Create a new http request pody based on the provided parameters

Types

type FleetLockRequest

type FleetLockRequest struct {
	Client FleetLockRequestClient `json:"client_params"`
}

func ParseRequest

func ParseRequest(body io.ReadCloser) (FleetLockRequest, error)

Parse an http request body and extract the parameters

type FleetLockRequestClient

type FleetLockRequestClient struct {
	ID    string `json:"id"`
	Group string `json:"group"`
}

type FleetLockResponse

type FleetLockResponse struct {
	Kind  string `json:"kind"`
	Value string `json:"value"`
}

func ParseResponse

func ParseResponse(body io.ReadCloser) (FleetLockResponse, error)

Parse an http response body and extract the parameters

type FleetlockHealthResponse

type FleetlockHealthResponse struct {
	Status string `json:"status"`
	Error  string `json:"error"`
}

Jump to